# Generated by roxygen2: do not edit by hand

S3method("+",lws_table)
S3method(AIC,midas_r_np)
S3method(BIC,midas_r_np)
S3method(bread,midas_r)
S3method(coef,midas_nlpr)
S3method(coef,midas_qr)
S3method(coef,midas_r)
S3method(coef,midas_sp)
S3method(deriv_tests,midas_r)
S3method(deviance,midas_nlpr)
S3method(deviance,midas_r)
S3method(deviance,midas_sp)
S3method(estfun,midas_r)
S3method(fitted,midas_nlpr)
S3method(fitted,midas_sp)
S3method(forecast,midas_r)
S3method(forecast,midas_r_np)
S3method(forecast,midas_u)
S3method(get_datex,ts)
S3method(get_datex,zoo)
S3method(get_datey,default)
S3method(get_datey,ts)
S3method(get_datey,zoo)
S3method(get_frequency_info,default)
S3method(get_frequency_info,midas_r)
S3method(logLik,midas_r)
S3method(plot_midas_coef,midas_nlpr)
S3method(plot_midas_coef,midas_r)
S3method(plot_midas_coef,midas_sp)
S3method(predict,midas_nlpr)
S3method(predict,midas_r)
S3method(predict,midas_r_np)
S3method(predict,midas_sp)
S3method(predict,midas_u)
S3method(print,lws_table)
S3method(print,midas_nlpr)
S3method(print,midas_qr)
S3method(print,midas_r)
S3method(print,midas_r_ic_table)
S3method(print,midas_r_np)
S3method(print,midas_sp)
S3method(print,summary.midas_nlpr)
S3method(print,summary.midas_qr)
S3method(print,summary.midas_r)
S3method(print,summary.midas_sp)
S3method(simulate,midas_r)
S3method(summary,midas_nlpr)
S3method(summary,midas_qr)
S3method(summary,midas_r)
S3method(summary,midas_r_np)
S3method(summary,midas_sp)
S3method(update,midas_nlpr)
S3method(update,midas_r)
S3method(update,midas_r_ic_table)
S3method(update,midas_sp)
S3method(vcov,midas_r)
export(agk.test)
export(almonp)
export(almonp_gradient)
export(amidas_table)
export(amweights)
export(average_forecast)
export(check_mixfreq)
export(deriv_tests)
export(dmls)
export(expand_amidas)
export(expand_weights_lags)
export(extract.midas_r)
export(fmls)
export(forecast)
export(genexp)
export(genexp_gradient)
export(get_estimation_sample)
export(gompertzp)
export(gompertzp_gradient)
export(hAh_test)
export(hAhr_test)
export(harstep)
export(harstep_gradient)
export(hf_lags_table)
export(imidas_r)
export(lcauchyp)
export(lcauchyp_gradient)
export(lf_lags_table)
export(lstr)
export(midas_auto_sim)
export(midas_lstr_plain)
export(midas_lstr_sim)
export(midas_mmm_plain)
export(midas_mmm_sim)
export(midas_nlpr)
export(midas_pl_plain)
export(midas_pl_sim)
export(midas_qr)
export(midas_r)
export(midas_r_ic_table)
export(midas_r_np)
export(midas_r_plain)
export(midas_si_plain)
export(midas_si_sim)
export(midas_sim)
export(midas_sp)
export(midas_u)
export(mls)
export(mlsd)
export(mmm)
export(modsel)
export(nakagamip)
export(nakagamip_gradient)
export(nbeta)
export(nbetaMT)
export(nbetaMT_gradient)
export(nbeta_gradient)
export(nealmon)
export(nealmon_gradient)
export(plot_lstr)
export(plot_midas_coef)
export(plot_sp)
export(polystep)
export(polystep_gradient)
export(select_and_forecast)
export(simulate)
export(split_data)
export(update_weights)
export(weights_table)
import(Matrix)
import(numDeriv)
import(optimx)
import(quantreg)
import(sandwich)
importFrom(Formula,Formula)
importFrom(MASS,ginv)
importFrom(forecast,forecast)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(methods,setMethod)
importFrom(numDeriv,jacobian)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,as.ts)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,delete.response)
importFrom(stats,deltat)
importFrom(stats,density)
importFrom(stats,deviance)
importFrom(stats,dnorm)
importFrom(stats,end)
importFrom(stats,filter)
importFrom(stats,fitted)
importFrom(stats,fitted.values)
importFrom(stats,formula)
importFrom(stats,frequency)
importFrom(stats,getCall)
importFrom(stats,lag)
importFrom(stats,lm)
importFrom(stats,lsfit)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,simulate)
importFrom(stats,terms)
importFrom(stats,time)
importFrom(stats,ts)
importFrom(stats,tsp)
importFrom(stats,update.formula)
importFrom(stats,window)
importFrom(texreg,createTexreg)
importFrom(texreg,extract)
importFrom(utils,capture.output)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(zoo,index)
importFrom(zoo,index2char)
